==> mongodb-7.0.23.gh.tar.gz: mongo-r7.0.23/src/mongo/db/query/optimizer/metadata_factory.h <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/query/optimizer/metadata.h"


namespace mongo::optimizer {

ScanDefinition createScanDef(ScanDefOptions options,
                             opt::unordered_map<std::string, IndexDefinition> indexDefs);

ScanDefinition createScanDef(ScanDefOptions options,
                             opt::unordered_map<std::string, IndexDefinition> indexDefs,
                             const ConstFoldFn& constFold,
                             DistributionAndPaths distributionAndPaths,
                             bool exists = true,
                             CEType ce = CEType{-1.0});

}  // namespace mongo::optimizer

==> mongodb-8.0.8.gh.tar.gz: mongo-r8.0.8/src/mongo/db/query/optimizer/metadata_factory.h <==
/**
 *    Copyright (C) 2022-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <boost/none.hpp>
#include <boost/optional/optional.hpp>

#include "mongo/db/query/optimizer/defs.h"
#include "mongo/db/query/optimizer/metadata.h"
#include "mongo/db/query/optimizer/utils/const_fold_interface.h"
#include "mongo/db/query/optimizer/utils/utils.h"


namespace mongo::optimizer {

MultikeynessTrie createTrie(const IndexDefinitions& indexDefs);

ScanDefinition createScanDef(ScanDefOptions options, IndexDefinitions indexDefs);

ScanDefinition createScanDef(ScanDefOptions options,
                             IndexDefinitions indexDefs,
                             const ConstFoldFn& constFold,
                             DistributionAndPaths distributionAndPaths,
                             bool exists = true,
                             boost::optional<CEType> ce = boost::none,
                             const PathToIntervalFn& pathToInterval = {});

ScanDefinition createScanDef(DatabaseName dbName,
                             boost::optional<UUID> uuid,
                             ScanDefOptions options,
                             IndexDefinitions indexDefs,
                             MultikeynessTrie multikeynessTrie,
                             const ConstFoldFn& constFold,
                             DistributionAndPaths distributionAndPaths,
                             bool exists = true,
                             boost::optional<CEType> ce = boost::none,
                             ShardingMetadata shardingMetadata = {},
                             const PathToIntervalFn& pathToInterval = {},
                             ScanOrder scanOrder = ScanOrder::Forward);

}  // namespace mongo::optimizer
